@@ -41,7 +41,7 @@ class MetaMax extends CMSModule
 
   function GetVersion()
   {
-    return '1.6.9.1';
+    return '1.7';
   }
 
   function GetHelp()
