@@ -27,9 +27,17 @@ if ($this->GetPreference('block_title','') != '') {
 } else {
     $description_block = '';
 }
+if ($this->GetPreference('content_var_title','') != '') {
+    $contentVar = $this->GetPreference('content_var_title','');
+    $contentVar = str_replace(' ','', $contentVar);
+    $contentVar = explode(',', $contentVar);
+} else {
+    $contentVar = '';
+}
+
+
 $pageSmarty = $this->GetPreference('page_smarty','');
 
-print_r ($entry->module);
 
 
 ///// KEYWORDS /////
@@ -40,7 +48,12 @@ $worddensity = $this->GetPreference('key_density','3');
 $checkContent = $curcontent->GetPropertyValue('content_en');
 
 if ($checkContent != '') {
-    $keywords = $curcontent->GetPropertyValue('content_en');
+    foreach ($contentVar as $key => $countVar) {
+        $countVars[] = $smarty->get_template_vars($countVar);
+    }
+    $countVars = join(' ', $countVars);
+    $contentBasic = $curcontent->GetPropertyValue('content_en');
+    $keywords = $contentBasic . $countVars;
     $keywords = preg_replace('/[\n\r]/','',$keywords);
     $keywords = preg_replace('/[\.\,]/','',$keywords);
     $keywords = str_replace('><','> <',$keywords);
@@ -135,7 +148,12 @@ if ($curcontent->GetPropertyValue($description_block) != '') {
     $desc = htmlentities($desc, ENT_COMPAT, 'UTF-8');
     $desc = utf8_encode(html_entity_decode($desc));
 } elseif ($this->GetPreference('auto_title','1') == 1 && $curcontent->GetPropertyValue($description_block) == '') {
-    $desc = $curcontent->GetPropertyValue('content_en');
+    foreach ($contentVar as $key => $countVar2) {
+        $countVars2[] = $smarty->get_template_vars($countVar2);
+    }
+    $countVars2 = join(' ', $countVars2);
+    $contentBasic2 = $curcontent->GetPropertyValue('content_en');
+    $desc = $contentBasic2 . $countVars2;
     $desc = preg_replace('/[\n\r]/','',$desc);
     $desc = str_replace('><','> <',$desc);
     $desc = strip_tags(str_replace('"','',$desc));
@@ -146,7 +164,12 @@ if ($curcontent->GetPropertyValue($description_block) != '') {
     $desclength = $this->GetPreference('length_title','30');
     $desc = preg_replace('/((\w+\W*){'.($desclength-1).'}(\w+))(.*)/', '${1}', $desc);
 } elseif ($this->GetPreference('auto_title','1') == 1) {
-    $desc = $curcontent->GetPropertyValue('content_en');
+    foreach ($contentVar as $key => $countVar2) {
+        $countVars2[] = $smarty->get_template_vars($countVar2);
+    }
+    $countVars2 = join(' ', $countVars2);
+    $contentBasic2 = $curcontent->GetPropertyValue('content_en');
+    $desc = $contentBasic2 . $countVars2;
     $desc = preg_replace('/[\n\r]/','',$desc);
     $desc = str_replace('><','> <',$desc);
     $desc = strip_tags(str_replace('"','',$desc));
@@ -222,6 +245,7 @@ if ($this->GetPreference('allow_add',1) == 1) {
    $this->smarty->assign('meta_block', $curcontent->GetPropertyValue($meta_block));
    $this->smarty->assign('description_block', $curcontent->GetPropertyValue($description_block));
    $this->smarty->assign('page_description', $desc);
+   $this->smarty->assign('contentText', $countVars);
 }
 
 
@@ -237,5 +261,6 @@ if (isset($params['module_message'])) {
 ///// PROCESS AND DISPLAY TEMPLATE /////
 
 echo $this->ProcessTemplate('metamax.tpl');
+//print_r($countVars);
 
 ?>
\ No newline at end of file
