@@ -37,6 +37,8 @@ $lang['delimiter_title'] = 'Page title delimiter';
 $lang['delimiter_title_help'] = 'This is the symbol used to seperate your title text';
 $lang['meta_block_title'] = 'Name of metadata content block';
 $lang['meta_block_title_help'] = 'This should be the name given to your metadata content block, check module help for more info';
+$lang['content_var_title'] = 'Content block variables';
+$lang['content_var_title_help'] = 'A comma seperated list of variables';
 $lang['block_title'] = 'Name of page description content block';
 $lang['block_title_help'] = 'This should be the name given to your page description content block, check module help for more info';
 $lang['length_title'] = 'Number of words to appear in auto description';
@@ -144,7 +146,8 @@ $lang['changelog'] = '<ul>
 <li>Version 1.6.7. 22 February 2012. Bug fixes and addition of Metadata content block to enable page specific metadata.</li>
 <li>Version 1.6.8. 24 February 2012. Minor bug fix.</li>
 <li>Version 1.6.9. 25 February 2012. Bug fix #7638 and #7639.</li>
-<li>Version 1.6.9.1. 25 February 2012. Made PHP 5.2 compatible to fix bug #7638.</li></ul>';
+<li>Version 1.6.9.1. 25 February 2012. Made PHP 5.2 compatible to fix bug #7638.</li>
+<li>Version 1.7. 26 February 2012. Added the ability to specify multiple content blocks from where pages keywords and descriptions are created from assigned variables.</li></ul>';
 $lang['help'] = '<h3>What Does This Do?</h3>
 <p>This module adds the ability to include additional Meta data, Analytics tracking code and other useful SEO information. It can also be used to generate Doctype and Head tags, replacing the entire head of your document.</p>
 <h3>How Do I Use It</h3>
